{# Partial template for displaying MCPO status #}
{# Expects 'mcpo_status' variable (string: RUNNING, STOPPED, ERROR, UNKNOWN) #}
{# and optionally 'message' #}
<div style="font-size: 1.1em; margin-bottom: 10px;">
    <strong>MCPO Status:</strong>
    {% if mcpo_status == "RUNNING" %}
        <span class="green-text text-darken-1"><i class="material-icons tiny left" style="vertical-align: middle;">check_circle</i>Running</span>
    {% elif mcpo_status == "STOPPED" %}
        <span class="grey-text text-darken-1"><i class="material-icons tiny left" style="vertical-align: middle;">pause_circle_outline</i>Stopped</span>
     {% elif mcpo_status == "ERROR" %}
         <span class="red-text text-darken-1"><i class="material-icons tiny left" style="vertical-align: middle;">error_outline</i>Error</span> (process not found, check logs)
    {% else %}
        <span class="orange-text text-darken-1"><i class="material-icons tiny left" style="vertical-align: middle;">help_outline</i>Unknown</span>
    {% endif %}
</div>
{% if message %}
    <p class="grey-text text-darken-2" style="font-size: 0.9em; margin-top: 0;"><em><i class="material-icons tiny left">info_outline</i>Message: {{ message }}</em></p>
{% endif %}